@@ -148,6 +148,12 @@ random.RevWeibull <- function(x, n = 1L, drop = TRUE, ...) {
 #' @param x A vector of elements whose probabilities you would like to
 #'   determine given the distribution `d`.
 #' @param drop logical. Should the result be simplified to a vector if possible?
+#' @param elementwise logical. Should each distribution in \code{d} be evaluated
+#'   at all elements of \code{x} (\code{elementwise = FALSE}, yielding a matrix)?
+#'   Or, if \code{d} and \code{x} have the same length, should the evaluation be
+#'   done element by element (\code{elementwise = TRUE}, yielding a vector)? The
+#'   default of \code{NULL} means that \code{elementwise = TRUE} is used if the
+#'   lengths match and otherwise \code{elementwise = FALSE} is used.
 #' @param ... Arguments to be passed to \code{\link[revdbayes]{dgev}}.
 #'   Unevaluated arguments will generate a warning to catch mispellings or other
 #'   possible errors.
@@ -158,7 +164,7 @@ random.RevWeibull <- function(x, n = 1L, drop = TRUE, ...) {
 #'   object, a matrix with `length(x)` columns containing all possible combinations.
 #' @export
 #'
-pdf.RevWeibull <- function(d, x, drop = TRUE, ...) {
+pdf.RevWeibull <- function(d, x, drop = TRUE, elementwise = NULL, ...) {
   # Convert to the GEV parameterisation
   FUN <- function(at, d) {
     loc <- d$location - d$scale
@@ -166,13 +172,13 @@ pdf.RevWeibull <- function(d, x, drop = TRUE, ...) {
     shape <- -1 / d$shape
     revdbayes::dgev(x = at, loc = loc, scale = scale, shape = shape, ...)
   }
-  apply_dpqr(d = d, FUN = FUN, at = x, type = "density", drop = drop)
+  apply_dpqr(d = d, FUN = FUN, at = x, type = "density", drop = drop, elementwise = elementwise)
 }
 
 #' @rdname pdf.RevWeibull
 #' @export
 #'
-log_pdf.RevWeibull <- function(d, x, drop = TRUE, ...) {
+log_pdf.RevWeibull <- function(d, x, drop = TRUE, elementwise = NULL, ...) {
   # Convert to the GEV parameterisation
   FUN <- function(at, d) {
     loc <- d$location - d$scale
@@ -180,7 +186,7 @@ log_pdf.RevWeibull <- function(d, x, drop = TRUE, ...) {
     shape <- -1 / d$shape
     revdbayes::dgev(x = at, loc = loc, scale = scale, shape = shape, log = TRUE)
   }
-  apply_dpqr(d = d, FUN = FUN, at = x, type = "logLik", drop = drop)
+  apply_dpqr(d = d, FUN = FUN, at = x, type = "logLik", drop = drop, elementwise = elementwise)
 }
 
 #' Evaluate the cumulative distribution function of an RevWeibull distribution
@@ -191,6 +197,12 @@ log_pdf.RevWeibull <- function(d, x, drop = TRUE, ...) {
 #' @param x A vector of elements whose cumulative probabilities you would
 #'   like to determine given the distribution `d`.
 #' @param drop logical. Should the result be simplified to a vector if possible?
+#' @param elementwise logical. Should each distribution in \code{d} be evaluated
+#'   at all elements of \code{x} (\code{elementwise = FALSE}, yielding a matrix)?
+#'   Or, if \code{d} and \code{x} have the same length, should the evaluation be
+#'   done element by element (\code{elementwise = TRUE}, yielding a vector)? The
+#'   default of \code{NULL} means that \code{elementwise = TRUE} is used if the
+#'   lengths match and otherwise \code{elementwise = FALSE} is used.
 #' @param ... Arguments to be passed to \code{\link[revdbayes]{pgev}}.
 #'   Unevaluated arguments will generate a warning to catch mispellings or other
 #'   possible errors.
@@ -201,7 +213,7 @@ log_pdf.RevWeibull <- function(d, x, drop = TRUE, ...) {
 #'   object, a matrix with `length(x)` columns containing all possible combinations.
 #' @export
 #'
-cdf.RevWeibull <- function(d, x, drop = TRUE, ...) {
+cdf.RevWeibull <- function(d, x, drop = TRUE, elementwise = NULL, ...) {
   # Convert to the GEV parameterisation
   FUN <- function(at, d) {
     loc <- d$location - d$scale
@@ -209,7 +221,7 @@ cdf.RevWeibull <- function(d, x, drop = TRUE, ...) {
     shape <- -1 / d$shape
     revdbayes::pgev(q = at, loc = loc, scale = scale, shape = shape, ...)
   }
-  apply_dpqr(d = d, FUN = FUN, at = x, type = "probability", drop = drop)
+  apply_dpqr(d = d, FUN = FUN, at = x, type = "probability", drop = drop, elementwise = elementwise)
 }
 
 #' Determine quantiles of a RevWeibull distribution
@@ -221,6 +233,12 @@ cdf.RevWeibull <- function(d, x, drop = TRUE, ...) {
 #'
 #' @param probs A vector of probabilities.
 #' @param drop logical. Should the result be simplified to a vector if possible?
+#' @param elementwise logical. Should each distribution in \code{x} be evaluated
+#'   at all elements of \code{probs} (\code{elementwise = FALSE}, yielding a matrix)?
+#'   Or, if \code{x} and \code{probs} have the same length, should the evaluation be
+#'   done element by element (\code{elementwise = TRUE}, yielding a vector)? The
+#'   default of \code{NULL} means that \code{elementwise = TRUE} is used if the
+#'   lengths match and otherwise \code{elementwise = FALSE} is used.
 #' @param ... Arguments to be passed to \code{\link[revdbayes]{qgev}}.
 #'   Unevaluated arguments will generate a warning to catch mispellings or other
 #'   possible errors.
@@ -232,9 +250,7 @@ cdf.RevWeibull <- function(d, x, drop = TRUE, ...) {
 #'   possible combinations.
 #' @export
 #'
-quantile.RevWeibull <- function(x, probs, drop = TRUE, ...) {
-  ellipsis::check_dots_used()
-
+quantile.RevWeibull <- function(x, probs, drop = TRUE, elementwise = NULL, ...) {
   # Convert to the GEV parameterisation
   FUN <- function(at, d) {
     loc <- d$location - d$scale
@@ -242,23 +258,33 @@ quantile.RevWeibull <- function(x, probs, drop = TRUE, ...) {
     shape <- -1 / d$shape
     revdbayes::qgev(p = at, loc = loc, scale = scale, shape = shape, ...)
   }
-  apply_dpqr(d = x, FUN = FUN, at = probs, type = "quantile", drop = drop)
+  apply_dpqr(d = x, FUN = FUN, at = probs, type = "quantile", drop = drop, elementwise = elementwise)
 }
 
 #' Return the support of the RevWeibull distribution
 #'
 #' @param d An `RevWeibull` object created by a call to [RevWeibull()].
 #' @param drop logical. Should the result be simplified to a vector if possible?
+#' @param ... Currently not used.
 #'
 #' @return A vector of length 2 with the minimum and maximum value of the support.
 #'
 #' @export
-support.RevWeibull <- function(d, drop = TRUE) {
-  stopifnot("d must be a supported distribution object" = is_distribution(d))
-  stopifnot(is.logical(drop))
-
+support.RevWeibull <- function(d, drop = TRUE, ...) {
+  ellipsis::check_dots_used()
   min <- rep(-Inf, length(d))
   max <- d$location
-
   make_support(min, max, d, drop = drop)
 }
+
+#' @exportS3Method
+is_discrete.RevWeibull <- function(d, ...) {
+  ellipsis::check_dots_used()
+  setNames(rep.int(FALSE, length(d)), names(d))
+}
+
+#' @exportS3Method
+is_continuous.RevWeibull <- function(d, ...) {
+  ellipsis::check_dots_used()
+  setNames(rep.int(TRUE, length(d)), names(d))
+}
